diff --git a/src/applications/cache/PhabricatorCaches.php b/src/applications/cache/PhabricatorCaches.php
--- a/src/applications/cache/PhabricatorCaches.php
+++ b/src/applications/cache/PhabricatorCaches.php
@@ -54,7 +54,7 @@
   private static function buildImmutableCaches() {
     $caches = array();
 
-    $apc = new PhutilKeyValueCacheAPC();
+    $apc = new PhutilAPCKeyValueCache();
     if ($apc->isAvailable()) {
       $caches[] = $apc;
     }
@@ -80,11 +80,11 @@
   private static function buildRepositoryGraphL1Caches() {
     $caches = array();
 
-    $request = new PhutilKeyValueCacheInRequest();
+    $request = new PhutilInRequestKeyValueCache();
     $request->setLimit(32);
     $caches[] = $request;
 
-    $apc = new PhutilKeyValueCacheAPC();
+    $apc = new PhutilAPCKeyValueCache();
     if ($apc->isAvailable()) {
       $caches[] = $apc;
     }
@@ -141,7 +141,7 @@
   private static function buildSetupCaches() {
     // In most cases, we should have APC. This is an ideal cache for our
     // purposes -- it's fast and empties on server restart.
-    $apc = new PhutilKeyValueCacheAPC();
+    $apc = new PhutilAPCKeyValueCache();
     if ($apc->isAvailable()) {
       return array($apc);
     }
@@ -150,7 +150,7 @@
     // much better than nothing; some setup steps are quite slow.
     $disk_path = self::getSetupCacheDiskCachePath();
     if ($disk_path) {
-      $disk = new PhutilKeyValueCacheOnDisk();
+      $disk = new PhutilOnDiskKeyValueCache();
       $disk->setCacheFile($disk_path);
       $disk->setWait(0.1);
       if ($disk->isAvailable()) {
diff --git a/src/applications/diviner/cache/DivinerDiskCache.php b/src/applications/diviner/cache/DivinerDiskCache.php
--- a/src/applications/diviner/cache/DivinerDiskCache.php
+++ b/src/applications/diviner/cache/DivinerDiskCache.php
@@ -5,7 +5,7 @@
   private $cache;
 
   public function __construct($cache_directory, $name) {
-    $dir_cache = id(new PhutilKeyValueCacheDirectory())
+    $dir_cache = id(new PhutilDirectoryKeyValueCache())
       ->setCacheDirectory($cache_directory);
     $profiled_cache = id(new PhutilKeyValueCacheProfiler($dir_cache))
       ->setProfiler(PhutilServiceProfiler::getInstance())
@@ -25,7 +25,7 @@
   /**
    * Convert a long-form hash key like `ccbbaaaaaaaaaaaaaaaaaaaaaaaaaaaaN` into
    * a shortened directory form, like `cc/bb/aaaaaaaaN`. In conjunction with
    * @{class:PhutilKeyValueCacheDirectory}, this gives us nice directories
    * inside .divinercache instead of a million hash files with huge names at
    * top level.
    */
@@ -25,7 +25,7 @@
    * Convert a long-form hash key like `ccbbaaaaaaaaaaaaaaaaaaaaaaaaaaaaN` into
    * a shortened directory form, like `cc/bb/aaaaaaaaN`. In conjunction with
-   * @{class:PhutilKeyValueCacheDirectory}, this gives us nice directories
+   * @{class:PhutilDirectoryKeyValueCache}, this gives us nice directories
    * inside .divinercache instead of a million hash files with huge names at
    * top level.